11. Support and Contact — Nikola 8.1.3 documentation

# 11. Support and Contact

Version

  8.1.3

Contents

- Support and Contact

  - Help and Support

    - Plugins and Themes

  - Report a Bug, Request a Feature

  - Administrativia

    - Administrators

## 11.1. Help and Support

1. A mailing list, nikola-discuss on Google Groups exists.

2. There’s an IRC channel: #nikola on Libera.Chat. You can find many developers and volunteers (users) there which are there to provide help, if they are around and read your message. The channels are publicly logged.

3. You can also contact @GetNikola on Twitter.

4. If you are experiencing a bug, you should report it on GitHub (see below).

### 11.1.1. Plugins and Themes

Plugins and Themes from the Indexes are not officially supported.

1. Ask the mailing list, which may or may not work out.

2. You can also try the IRC channel if the theme/plugin is very popular.

3. Report an issue at the plugins issue tracker or at the themes issue tracker.

4. Contact the author of the plugin/theme. The name of the author of a plugin is available in the `.plugin` and `.py` files. Tracking down theme authors can be much harder due to how our architecture works (but certainly is doable).

## 11.2. Report a Bug, Request a Feature

Bug reports should be sent to the Issue tracker at GitHub.

Feature requests should be sent to the Issue tracker or to the mailing list, especially if they require further discussion.

## 11.3. Administrativia

If you are in need of getting administrativia resolved, you may want to e-mail info@getnikola.com and therefore contact the people behind the project. Note that this email may not be used for support matters. Messages are forwarded to all three administrators, the names and personal addresses (if you need to contact them personally) of you can find below.

### 11.3.1. Administrators

Name | GitHub Nickname | Location | E-mail
--- | --- | --- | ---
Roberto Alsina | ralsina | Argentina | roberto@getnikola.com
Damián Avila | damianavila | Argentina | damian@getnikola.com
Daniel Aleksandersen | Aeyoun | Norway | daniel@getnikola.com
Chris Warrick | Kwpolska | Poland | chris@getnikola.com